@@ -113,11 +113,26 @@ impl Session {
     }
 
     /// Send a `ClientMsg` to the network without awaiting for a response.
-    pub async fn send_cmd(&self, cmd: Cmd, client_sig: ClientSig) -> Result<(), Error> {
+    pub async fn send_cmd(
+        &self,
+        cmd: Cmd,
+        client_sig: ClientSig,
+        send_to_specific_elder: Option<SocketAddr>,
+    ) -> Result<(), Error> {
         let msg_id = MessageId::new();
         let endpoint = self.endpoint()?.clone();
 
-        let elders: Vec<SocketAddr> = self.connected_elders.read().await.keys().cloned().collect();
+        let elders = if let Some(socket) = send_to_specific_elder {
+            vec![socket]
+        } else {
+            self.connected_elders
+                .read()
+                .await
+                .keys()
+                .cloned()
+                .collect::<Vec<SocketAddr>>()
+        };
+
         debug!(
             "Sending command w/id {:?}, to {} Elders",
             msg_id,
