@@ -151,20 +151,7 @@ async fn run_node() {
         }
     };
 
-    let node_prefix = node.our_prefix().await;
-    let node_name = node.our_name().await;
     let our_conn_info = node.our_connection_info();
-    let our_pid = std::process::id();
-    let our_conn_info_json = serde_json::to_string(&our_conn_info)
-        .unwrap_or_else(|_| "Failed to serialize connection info".into());
-    println!(
-        "Node PID: {:?}, prefix: {:?}, name: {}, connection info:\n{}",
-        our_pid, node_prefix, node_name, our_conn_info_json,
-    );
-    info!(
-        "Node PID: {:?}, prefix: {:?}, name: {}, connection info: {}",
-        our_pid, node_prefix, node_name, our_conn_info_json,
-    );
 
     if config.is_first() {
         set_connection_info(our_conn_info).unwrap_or_else(|err| {
